from django.contrib.auth.models import Group
from samklang_pages.models import Page
from django.utils.translation import ugettext_lazy as _
from samklang_utils.forms import MarkdownTextarea
import floppyforms as forms

class PageForm(forms.ModelForm):
    url = forms.RegexField(
            label=_("URL"),
            max_length=100,
            regex=r'^[-\w/]+$',
            help_text = _("Example: '/about/contact/'. Make sure to have leading"
                " and trailing slashes."),
            error_message = _("This value must contain only letters, numbers,"
                " underscores, dashes or slashes."),
            )
    group = forms.ModelChoiceField(Group.objects, empty_label=_("Public"), required=False, label=_("Read permission"))

    class Meta:
        model = Page
        fields = ('content', 'url', 'name', 'group', 'admingroup')
        widgets = {'content': MarkdownTextarea()}



from django.conf import settings
from django.core.exceptions import ObjectDoesNotExist
from samklang_pages.models import Page

class Widget(object):

    def __init__(self, options, *args, **kwargs):
        super(Widget, self).__init__(*args, **kwargs)
        self.options = options

    def get_display_name(self):
        raise NotImplementedError

    def render(self):
        raise NotImplementedError

    def render_option_form(self):
        raise NotImplementedError

    def get_option_dict(self):
        return self.options

class Image(Widget):
    """Image widget for adding an image"""

    def render(self):
        #print self.options
        retval = u"""
<img class="%(class)s" src="%(src)s" alt="%(alt)s" />
        """ % {
            'class': self.options.get('class', ''),
            'src': self.options.get('src', ''),
            'alt': self.options.get('alt', ''),
        }
        return retval

class StaticPage(Widget):
    """Fill in the contents of another static page into a widget"""

    def render(self):
        url = self.options.get('url')
        try:
            page = Page.objects.get(url=url)
            return page.content_html
        except ObjectDoesNotExist:
            return u""


class Slider(Widget):
    def render(self):
        """Render slider widget using options from json field"""

        javascript = u"""
        <script src="%(STATIC_URL)sjs/slides.min.jquery.js"></script>
		<script>
    		$(function(){
    			$('#slides').slides({
    				preload: true,
                    preloadImage: '%(STATIC_URL)simg/loading.gif',
    				play: 8000,
    				pause: 2000,
    				hoverPause: true,
    				animationStart: function(current){
    					$('.caption').animate({
    						bottom:-35
    					},100);
    				},
    				animationComplete: function(current){
    					$('.caption').animate({
    						bottom:0
    					},200);
    				},
    				slidesLoaded: function() {
    					$('.caption').animate({
    						bottom:0
    					},200);
    				}
    			});
    		});
    	</script>
        """ % {"STATIC_URL": settings.STATIC_URL}

        slides = [ u"""<div class="slide"><a href="%(url)s" title="%(title)s"><img src="%(src)s" width="386" height="283" alt="%(alt)s"></a><div class="caption" style="bottom:0"><p>%(title)s</p></div></div>""" % {'url': slide.get('url', slide.get('src')), 'title': slide.get('title', ''), 'alt': slide.get('alt', slide.get('title', '')), 'src': slide.get('src', '') } for slide in self.options.get("slides") ]

        html = u"""<div id="slides"><div class="slides_container">""" + "".join(slides) + u"""</div></div><img src="/static/img/frame.png" width="452" height="338" alt="Frame" id="frame">"""

        return javascript + html



from django.utils import simplejson

from django.db import models
from django.contrib.auth.models import User, Group
from django.contrib.sites.models import Site
from django.utils.translation import ugettext_lazy as _
from samklang_utils import markdown

class Page(models.Model):
    url = models.CharField(_('URL'), max_length=100, db_index=True)
    name = models.CharField(_('name'), max_length=50, help_text=_("Used for page list. Remember to create a heading in the content field."))
    content = models.TextField(_('content'), blank=True)
    content_html = models.TextField(null=True, blank=True)
    site = models.ForeignKey(Site, verbose_name=_('site'))
    user = models.ForeignKey(User, verbose_name=_('user'))
    group = models.ForeignKey(Group, related_name='pages', verbose_name=_('read permission'), null=True, blank=True)
    admingroup = models.ForeignKey(Group, related_name='administers_pages', verbose_name=_('write permission'))
    #document_class = models.SlugField(max_length=20, blank=True)

    class Meta:
        verbose_name = _('page')
        verbose_name_plural = _('pages')
        ordering = ('url',)
        db_table = 'samklang_page'

    def __unicode__(self):
        return u"%s -- %s" % (self.url, self.name)

    def get_absolute_url(self):
        return self.url

    def save(self, *args, **kwargs):
        self.content_html = markdown(self.content.strip())
        super(Page, self).save(*args, **kwargs)

class PageWidget(models.Model):
    page = models.ForeignKey(Page, verbose_name=_('page'), related_name='widget')
    widget_name = models.CharField(max_length=30)
    position = models.IntegerField(verbose_name=_('position'))
    options = models.TextField(blank=True, verbose_name=_('options'))

    class Meta:
        verbose_name = _('Page widget')
        verbose_name_plural = _('Page widgets')
        ordering = ('position', 'widget_name')
        db_table = 'samklang_pagewidget'

    def __unicode__(self):
        return u"%s: %s" % (self.widget_name, self.page.name)

    def widget(self):
        app, widget_name = self.widget_name.rsplit(".", 1)
        imp = __import__(app + ".pagewidgets", globals(), locals(), [widget_name])
        widget_class = getattr(imp, widget_name)
        try:
            options = simplejson.loads(self.options)
        except simplejson.JSONDecodeError:
            options = {}
        widget = widget_class(options)
        return widget




from django.contrib import admin
from samklang_pages.models import Page
from samklang_pages.forms import PageForm

class PageAdminForm(PageForm):

    class Meta:
        fields = ('url', 'name', 'content', 'site', 'user', 'group', 'admingroup',)# 'document_class')

class PageAdmin(admin.ModelAdmin):
    form = PageAdminForm
    list_display = ('url', 'name')
    search_fields = ('url', 'name')

admin.site.register(Page, PageAdmin)



from django.conf.urls.defaults import *
from samklang_pages.views import *

urlpatterns = patterns('samklang_pages.views',
    #(r'^(?P<url>.*)$', 'page'),
    url(r'new/$', PageCreateView.as_view(), name='pages-page-new'),
    url(r'edit/menu/(?P<page_id>\d+)/$', add_to_menu, name='pages-menu-add'),
    url(r'edit/(?P<pk>\d+)/$', PageUpdateView.as_view(), name='pages-page-edit'),
    url(r'$', PageListView.as_view(), name='pages-page-list'),
)



#!/usr/bin/env python
from distutils.core import setup

setup(
        name='samklang-pages',
        version="0.4.0",
        author='Sigurd Gartmann',
        author_email='sigurdga-samklang@sigurdga.no',
        url='http://github.com/sigurdga/samklang-pages',
        description='Pages module for Samklang',
        long_description=open('README.txt').read(),
        license="AGPL",
        packages=['samklang_pages', 'samklang_pages.migrations'],
        package_data={'samklang_pages': ['templates/samklang_pages/*.html', 'static/js/*.js', 'locale/*/LC_MESSAGES/django.*o']},
        classifiers=[
            "Development Status :: 3 - Alpha",
            "License :: OSI Approved :: GNU Affero General Public License v3",
            "Intended Audience :: Developers",
            "Framework :: Django",
            "Environment :: Web Environment",
            "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
            ]
        )
